@@ -40,7 +40,7 @@ module FakeFS
     end
 
     def children
-      each.to_a
+      each.to_a - ['.', '..']
     end
 
     def pos
